@@ -6,14 +6,13 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
 
 from Acquisition import aq_base
 from Globals import REPLACEABLE
 from DateTime import DateTime
 from Products.CMFCore.permissions import AccessInactivePortalContent
-from Products.CMFPlone import transaction
+import transaction
 
 from Products.CMFPlone.CatalogTool import ExtensibleIndexableObjectWrapper
 from Products.CMFPlone.CatalogTool import _eioRegistry
@@ -27,7 +26,8 @@ default_user  = PloneTestCase.default_user
 user2  = 'u2'
 group2 = 'g2'
 
-base_content = ['Members', 'events', 'news', 'previous', default_user, 'doc']
+base_content = ['Members', 'events', 'news', 'previous',
+                default_user, 'front-page', 'doc']
 
 
 class TestCatalogSetup(PloneTestCase.PloneTestCase):
@@ -162,36 +162,36 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         self.assertEqual(self.folder.doc.getId(), 'doc')
         self.assertEqual(self.folder.doc.Title(), 'Foo')
         self.assertEqual(self.folder.doc.Description(), 'Bar')
-        self.assertEqual(len(self.catalog(id='doc')), 0)
+        self.assertEqual(len(self.catalog(getId='doc')), 0)
         self.assertEqual(len(self.catalog(Title='Foo')), 0)
         self.assertEqual(len(self.catalog(Description='Bar')), 0)
 
     def testIndexObject(self):
         # Object should be indexed
         self.catalog.indexObject(self.folder.doc)
-        self.assertEqual(len(self.catalog(id='doc')), 1)
+        self.assertEqual(len(self.catalog(getId='doc')), 1)
         self.assertEqual(len(self.catalog(Title='Foo')), 1)
         self.assertEqual(len(self.catalog(Description='Bar')), 1)
 
     def testReindexObject(self):
         # Object should be indexed
         self.catalog.reindexObject(self.folder.doc)
-        self.assertEqual(len(self.catalog(id='doc')), 1)
+        self.assertEqual(len(self.catalog(getId='doc')), 1)
         self.assertEqual(len(self.catalog(Title='Foo')), 1)
         self.assertEqual(len(self.catalog(Description='Bar')), 1)
 
     def testUnindexObject(self):
         # Object should be unindexed
         self.catalog.indexObject(self.folder.doc)
-        self.assertEqual(len(self.catalog(id='doc')), 1)
+        self.assertEqual(len(self.catalog(getId='doc')), 1)
         self.catalog.unindexObject(self.folder.doc)
-        self.assertEqual(len(self.catalog(id='doc')), 0)
+        self.assertEqual(len(self.catalog(getId='doc')), 0)
 
     def testIndexObjectUpdatesMetadata(self):
         # Indexing should update metadata
         self.catalog.indexObject(self.folder.doc)
-        brain = self.catalog(id='doc')[0]
-        self.assertEqual(brain.id, 'doc')
+        brain = self.catalog(getId='doc')[0]
+        self.assertEqual(brain.getId, 'doc')
         self.assertEqual(brain.Title, 'Foo')
         self.assertEqual(brain.Description, 'Bar')
 
@@ -201,8 +201,8 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         self.folder.doc.setTitle('Fred')
         self.folder.doc.setDescription('BamBam')
         self.catalog.reindexObject(self.folder.doc)
-        brain = self.catalog(id='doc')[0]
-        self.assertEqual(brain.id, 'doc')
+        brain = self.catalog(getId='doc')[0]
+        self.assertEqual(brain.getId, 'doc')
         self.assertEqual(brain.Title, 'Fred')
         self.assertEqual(brain.Description, 'BamBam')
 
@@ -212,9 +212,9 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         self.folder.doc.setTitle('Fred')
         self.folder.doc.setDescription('BamBam')
         self.catalog.reindexObject(self.folder.doc, update_metadata=0)
-        brain = self.catalog(id='doc')[0]
+        brain = self.catalog(getId='doc')[0]
         # Metadata did not change
-        self.assertEqual(brain.id, 'doc')
+        self.assertEqual(brain.getId, 'doc')
         self.assertEqual(brain.Title, 'Foo')
         self.assertEqual(brain.Description, 'Bar')
 
@@ -224,7 +224,7 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         self.folder.doc.setTitle('Fred')
         self.folder.doc.setDescription('BamBam')
         self.catalog.reindexObject(self.folder.doc, idxs=['Title'])
-        self.assertEqual(len(self.catalog(id='doc')), 1)
+        self.assertEqual(len(self.catalog(getId='doc')), 1)
         self.assertEqual(len(self.catalog(Title='Fred')), 1)
         # Description index did not change
         self.assertEqual(len(self.catalog(Description='Bar')), 1)
@@ -236,8 +236,8 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         self.folder.doc.setTitle('Fred')
         self.folder.doc.setDescription('BamBam')
         self.catalog.reindexObject(self.folder.doc, idxs=['Title'])
-        brain = self.catalog(id='doc')[0]
-        self.assertEqual(brain.id, 'doc')
+        brain = self.catalog(getId='doc')[0]
+        self.assertEqual(brain.getId, 'doc')
         self.assertEqual(brain.Title, 'Fred')
         self.assertEqual(brain.Description, 'BamBam')
 
@@ -247,9 +247,9 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         self.folder.doc.setTitle('Fred')
         self.folder.doc.setDescription('BamBam')
         self.catalog.reindexObject(self.folder.doc, idxs=['Title'], update_metadata=0)
-        brain = self.catalog(id='doc')[0]
+        brain = self.catalog(getId='doc')[0]
         # Metadata did not change
-        self.assertEqual(brain.id, 'doc')
+        self.assertEqual(brain.getId, 'doc')
         self.assertEqual(brain.Title, 'Foo')
         self.assertEqual(brain.Description, 'Bar')
 
@@ -265,7 +265,7 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         path = self.catalog._CatalogTool__url(self.folder.doc)
         self.failUnless(path in self.catalog._catalog.paths.values())
         # But it is not returned when searching...
-        self.assertEqual(len(self.catalog(id='doc')), 0)
+        self.assertEqual(len(self.catalog(getId='doc')), 0)
         self.assertEqual(len(self.catalog(Title='Foo')), 0) # <-- Should be 1
         self.assertEqual(len(self.catalog(Description='Bar')), 0)
 
@@ -275,12 +275,12 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         # TODO: Demonstrate that the behavior is independent
         # of index type.
         #
-        self.catalog.indexObject(self.folder.doc, idxs=['id'])
+        self.catalog.indexObject(self.folder.doc, idxs=['getId'])
         # The document is cataloged
         path = self.catalog._CatalogTool__url(self.folder.doc)
         self.failUnless(path in self.catalog._catalog.paths.values())
         # But it is not returned when searching...
-        self.assertEqual(len(self.catalog(id='doc')), 0) # <-- Should be 1
+        self.assertEqual(len(self.catalog(getId='doc')), 0) # <-- Should be 1
         self.assertEqual(len(self.catalog(Title='Foo')), 0)
         self.assertEqual(len(self.catalog(Description='Bar')), 0)
 
@@ -316,6 +316,14 @@ class TestCatalogIndexing(PloneTestCase.PloneTestCase):
         res = self.catalog.searchResults()
         self.assertResults(res, base_content)
 
+    def testClearFindAndRebuildKeepsModificationDate(self):
+        # Index the doc for consistency
+        self.catalog.indexObject(self.folder.doc)
+        self.folder.doc.setModificationDate(DateTime(0))
+        self.catalog.clearFindAndRebuild()
+        self.assertEquals(self.folder.doc.modified(), DateTime(0))
+        self.assertEquals(len(self.catalog(modified=DateTime(0))), 1)
+
 
 class TestCatalogSearching(PloneTestCase.PloneTestCase):
 
@@ -341,11 +349,10 @@ class TestCatalogSearching(PloneTestCase.PloneTestCase):
         self.groups.groupWorkspacesCreationFlag = 0
         self.groups.addGroup(group2, None, [], [])
         group = self.groups.getGroupById(group2)
-        self.loginPortalOwner() # GRUF 3.52
+        self.loginAsPortalOwner() # GRUF 3.52
         group.addMember(user2)
         self.login(default_user) # Back to normal
-        prefix = self.portal.acl_users.getGroupPrefix()
-        return '%s%s' % (prefix, group2)
+        return group2
 
     def testListAllowedRolesAndUsers(self):
         # Should include the group in list of allowed users
@@ -450,7 +457,7 @@ class TestCatalogSorting(PloneTestCase.PloneTestCase):
     def testSortableTitleOutput(self):
         doc = self.folder.doc
         wrapped = ExtensibleIndexableObjectWrapper(vars, doc, self.portal)
-        
+
         self.assertEqual(wrapped.sortable_title, u'00000012 document 00000025')
 
     def testSortableNonASCIITitles(self):
@@ -463,7 +470,7 @@ class TestCatalogSorting(PloneTestCase.PloneTestCase):
 
 
 class TestFolderCataloging(PloneTestCase.PloneTestCase):
-    # Tests for http://plone.org/collector/2876
+    # Tests for http://dev.plone.org/plone/ticket/2876
     # folder_edit must recatalog. folder_rename must recatalog.
 
     def afterSetUp(self):
@@ -479,7 +486,7 @@ class TestFolderCataloging(PloneTestCase.PloneTestCase):
         self.failUnless(results)
         for result in results:
             self.assertEqual(result.Title, title)
-            self.assertEqual(result.id, 'foo')
+            self.assertEqual(result.getId, 'foo')
 
     def testFolderTitleIsUpdatedOnRename(self):
         # Test for catalog that searches to ensure folder titles are
@@ -491,7 +498,7 @@ class TestFolderCataloging(PloneTestCase.PloneTestCase):
         self.failUnless(results)
         for result in results:
             self.assertEqual(result.Title, title)
-            self.assertEqual(result.id, 'bar')
+            self.assertEqual(result.getId, 'bar')
 
     def testFolderTitleIsUpdatedOnFolderTitleChange(self):
         # The bug in fact talks about folder_rename
@@ -502,7 +509,7 @@ class TestFolderCataloging(PloneTestCase.PloneTestCase):
         self.failUnless(results)
         for result in results:
             self.assertEqual(result.Title, title)
-            self.assertEqual(result.id, 'foo')
+            self.assertEqual(result.getId, 'foo')
 
     def testFolderTitleIsUpdatedOnFolderRename(self):
         # The bug in fact talks about folder_rename
@@ -514,12 +521,12 @@ class TestFolderCataloging(PloneTestCase.PloneTestCase):
         self.failUnless(results)
         for result in results:
             self.assertEqual(result.Title, title)
-            self.assertEqual(result.id, 'bar')
+            self.assertEqual(result.getId, 'bar')
 
     def testSetTitleDoesNotUpdateCatalog(self):
         # setTitle() should not update the catalog
         title = 'Test Folder - Snooze!'
-        self.failUnless(self.catalog(id='foo'))
+        self.failUnless(self.catalog(getId='foo'))
         self.folder.foo.setTitle(title)
         #Title is a TextIndex
         self.failIf(self.catalog(Title='Snooze'))
@@ -545,7 +552,7 @@ class TestCatalogOrdering(PloneTestCase.PloneTestCase):
         folder_docs = self.catalog(portal_type = 'Document',
                                    path = self.folder.getPhysicalPath(),
                                    sort_on = 'getObjPositionInParent')
-        expected = ['doc2','doc1','doc3','doc4']
+        expected = ['doc2','doc1','doc3','doc4', 'front-page']
         self.failUnlessEqual([b.getId for b in folder_docs], expected)
 
     def testOrderIsUpdatedOnMoveUp(self):
@@ -553,7 +560,7 @@ class TestCatalogOrdering(PloneTestCase.PloneTestCase):
         folder_docs = self.catalog(portal_type = 'Document',
                                    path = self.folder.getPhysicalPath(),
                                    sort_on = 'getObjPositionInParent')
-        expected = ['doc1','doc3','doc2','doc4']
+        expected = ['doc1','doc3','doc2','doc4', 'front-page']
         self.failUnlessEqual([b.getId for b in folder_docs], expected)
 
     def testOrderIsUpdatedOnMoveTop(self):
@@ -561,7 +568,7 @@ class TestCatalogOrdering(PloneTestCase.PloneTestCase):
         folder_docs = self.catalog(portal_type = 'Document',
                                    path = self.folder.getPhysicalPath(),
                                    sort_on = 'getObjPositionInParent')
-        expected = ['doc3','doc1','doc2','doc4']
+        expected = ['doc3','doc1','doc2','doc4', 'front-page']
         self.failUnlessEqual([b.getId for b in folder_docs], expected)
 
     def testOrderIsUpdatedOnMoveBottom(self):
@@ -569,7 +576,7 @@ class TestCatalogOrdering(PloneTestCase.PloneTestCase):
         folder_docs = self.catalog(portal_type = 'Document',
                                    path = self.folder.getPhysicalPath(),
                                    sort_on = 'getObjPositionInParent')
-        expected = ['doc1','doc2','doc4','doc3']
+        expected = ['doc1','doc2','doc4','doc3', 'front-page']
         self.failUnlessEqual([b.getId for b in folder_docs], expected)
 
     def testOrderIsFineWithObjectCreation(self):
@@ -577,7 +584,7 @@ class TestCatalogOrdering(PloneTestCase.PloneTestCase):
         folder_docs = self.catalog(portal_type = 'Document',
                                    path = self.folder.getPhysicalPath(),
                                    sort_on = 'getObjPositionInParent')
-        expected = ['doc1','doc2','doc3','doc4','doc5']
+        expected = ['doc1','doc2','doc3','doc4','doc5', 'front-page']
         self.failUnlessEqual([b.getId for b in folder_docs], expected)
 
     def testOrderIsFineWithObjectDeletion(self):
@@ -585,7 +592,7 @@ class TestCatalogOrdering(PloneTestCase.PloneTestCase):
         folder_docs = self.catalog(portal_type = 'Document',
                                    path = self.folder.getPhysicalPath(),
                                    sort_on = 'getObjPositionInParent')
-        expected = ['doc1','doc2','doc4']
+        expected = ['doc1','doc2','doc4', 'front-page']
         self.failUnlessEqual([b.getId for b in folder_docs], expected)
 
     def testOrderIsFineWithObjectRenaming(self):
@@ -600,7 +607,7 @@ class TestCatalogOrdering(PloneTestCase.PloneTestCase):
         folder_docs = self.catalog(portal_type = 'Document',
                                    path = self.folder.getPhysicalPath(),
                                    sort_on = 'getObjPositionInParent')
-        expected = ['doc1','buzz','doc3','doc4']
+        expected = ['doc1','buzz','doc3','doc4', 'front-page']
         self.failUnlessEqual([b.getId for b in folder_docs], expected)
 
     def testOrderAfterALotOfChanges(self):
@@ -622,7 +629,7 @@ class TestCatalogOrdering(PloneTestCase.PloneTestCase):
         #self.folder.manage_renameObjects('Document', id='doc5', text='blam')
 
         self.folder.manage_delObjects(['doc3','doc4','doc5','doc7'])
-        expected = ['doc2','doc1','doc6','doc8']
+        expected = ['doc2','doc1','doc6','doc8', 'front-page']
 
         folder_docs = self.catalog(portal_type = 'Document',
                                    path = self.folder.getPhysicalPath(),
@@ -654,7 +661,7 @@ class TestCatalogBugs(PloneTestCase.PloneTestCase):
         # Should be able to copy/paste a portal containing
         # a catalog tool. Triggers manage_afterAdd of portal_catalog
         # thereby exposing a bug which is now going to be fixed.
-        self.loginPortalOwner()
+        self.loginAsPortalOwner()
         cb = self.app.manage_copyObjects([portal_name])
         self.app.manage_pasteObjects(cb)
         self.failUnless(hasattr(self.app, 'copy_of_'+portal_name))
@@ -682,15 +689,15 @@ class TestCatalogBugs(PloneTestCase.PloneTestCase):
 
     def testCanRenamePortalIfLexiconExists(self):
         # Should be able to rename a Plone portal
-        # This test is to demonstrate that http://plone.org/collector/1745
+        # This test is to demonstrate that http://dev.plone.org/plone/ticket/1745
         # is fixed and can be closed.
-        self.loginPortalOwner()
+        self.loginAsPortalOwner()
         self.app.manage_renameObjects([portal_name], ['foo'])
         self.failUnless(hasattr(self.app, 'foo'))
 
 
 class TestCatalogUnindexing(PloneTestCase.PloneTestCase):
-    # Tests for http://plone.org/collector/3547
+    # Tests for http://dev.plone.org/plone/ticket/3547
     # Published objects are not unindexed on delete?
 
     def afterSetUp(self):
@@ -703,41 +710,41 @@ class TestCatalogUnindexing(PloneTestCase.PloneTestCase):
         self.assertEqual(state, 'visible')
 
     def testVisibleCanBeFound(self):
-        self.failUnless(self.catalog(id='doc'))
+        self.failUnless(self.catalog(getId='doc'))
 
     def testVisibleIsUnindexed(self):
         self.folder._delObject('doc')
-        self.failIf(self.catalog(id='doc'))
+        self.failIf(self.catalog(getId='doc'))
 
     def testPrivateCanBeFound(self):
         self.workflow.doActionFor(self.folder.doc, 'hide')
-        self.failUnless(self.catalog(id='doc'))
+        self.failUnless(self.catalog(getId='doc'))
 
     def testPrivateIsUnindexed(self):
         self.workflow.doActionFor(self.folder.doc, 'hide')
         self.folder._delObject('doc')
-        self.failIf(self.catalog(id='doc'))
+        self.failIf(self.catalog(getId='doc'))
 
     def testPendingCanBeFound(self):
         self.workflow.doActionFor(self.folder.doc, 'submit')
-        self.failUnless(self.catalog(id='doc'))
+        self.failUnless(self.catalog(getId='doc'))
 
     def testPendingIsUnindexed(self):
         self.workflow.doActionFor(self.folder.doc, 'submit')
         self.folder._delObject('doc')
-        self.failIf(self.catalog(id='doc'))
+        self.failIf(self.catalog(getId='doc'))
 
     def testPublishedCanBeFound(self):
         self.setRoles(['Manager'])
         self.workflow.doActionFor(self.folder.doc, 'publish')
-        self.failUnless(self.catalog(id='doc'))
+        self.failUnless(self.catalog(getId='doc'))
 
     def testPublishedIsUnindexed(self):
         # Works here!
         self.setRoles(['Manager'])
         self.workflow.doActionFor(self.folder.doc, 'publish')
         self.folder._delObject('doc')
-        self.failIf(self.catalog(id='doc'))
+        self.failIf(self.catalog(getId='doc'))
 
     def testPublishedIsUnindexedIfOwnerDeletes(self):
         # Works here!
@@ -745,7 +752,7 @@ class TestCatalogUnindexing(PloneTestCase.PloneTestCase):
         self.workflow.doActionFor(self.folder.doc, 'publish')
         self.setRoles(['Member'])
         self.folder._delObject('doc')
-        self.failIf(self.catalog(id='doc'))
+        self.failIf(self.catalog(getId='doc'))
 
     def testPublishedIsUnindexedByFolderDeleteScript(self):
         # Works here too!
@@ -754,8 +761,10 @@ class TestCatalogUnindexing(PloneTestCase.PloneTestCase):
         self.setRoles(['Member'])
         doc_path = '/'.join(self.folder.doc.getPhysicalPath())
         self.app.REQUEST.set('paths', [doc_path])
+        # folder_delete requires a non-GET request
+        self.app.REQUEST.set('REQUEST_METHOD', 'POST')
         self.folder.folder_delete()
-        self.failIf(self.catalog(id='doc'))
+        self.failIf(self.catalog(getId='doc'))
 
     def testPublishedIsUnindexedWhenDeletingParentFolder(self):
         # Works here too!
@@ -763,7 +772,7 @@ class TestCatalogUnindexing(PloneTestCase.PloneTestCase):
         self.workflow.doActionFor(self.folder.doc, 'publish')
         self.setRoles(['Member'])
         self.folder.aq_parent._delObject(self.folder.getId())
-        self.failIf(self.catalog(id='doc'))
+        self.failIf(self.catalog(getId='doc'))
 
 
 class TestCatalogExpirationFiltering(PloneTestCase.PloneTestCase):
@@ -841,6 +850,35 @@ class TestCatalogExpirationFiltering(PloneTestCase.PloneTestCase):
         res = self.catalog()
         self.assertResults(res, base_content)
 
+    def testSearchResultsWithAdditionalExpiryFilter(self):
+        # For this test we want the expires and effective indices in place,
+        # let's make sure everything still works
+        self.folder.doc.setExpirationDate(DateTime(2000, 12, 31))
+        self.folder.doc.reindexObject()
+        res = self.catalog.searchResults()
+        self.assertResults(res, base_content[:-1])
+        # Now make the object expire at some fixed date in the future
+        self.folder.doc.setExpirationDate(DateTime()+2)
+        self.folder.doc.reindexObject()
+        res = self.catalog.searchResults()
+        self.assertResults(res, base_content)
+        # We should be able to further limit the search using the exipres
+        # and efective indices.
+        res = self.catalog.searchResults(expires={'query':DateTime()+3,
+                                                  'range':'min'})
+        self.assertResults(res, base_content[:-1])
+
+    def testSearchResultsExpiredWithAdditionalExpiryFilter(self):
+        # Now make the object expire at some date in the recent past
+        self.folder.doc.setExpirationDate(DateTime()-2)
+        self.folder.doc.reindexObject()
+        res = self.catalog.searchResults()
+        self.assertResults(res, base_content[:-1])
+        # Even if we explicitly ask for it, we shouldn't get expired content
+        res = self.catalog.searchResults(expires={'query':DateTime()-3,
+                                                  'range':'min'})
+        self.assertResults(res, base_content[:-1])
+
 
 def dummyMethod(obj, **kwargs):
     return 'a dummy'
@@ -848,17 +886,17 @@ def dummyMethod(obj, **kwargs):
 class TestExtensibleIndexableObjectWrapper(PloneTestCase.PloneTestCase):
     """Tests for the wrapper
     """
-    
+
     def afterSetUp(self):
         self.folder.invokeFactory('Document', 'doc', title='document')
         self.doc = self.folder.doc
         _eioRegistry.register('dummy', dummyMethod)
-        
+
     def testSetup(self):
         doc = self.doc
         self.failUnlessEqual(doc.getId(), 'doc')
         self.failUnlessEqual(doc.Title(), 'document')
-        
+
     def testWrapper(self):
         doc = self.doc
         vars = {'var' : 'a var'}
@@ -867,7 +905,7 @@ class TestExtensibleIndexableObjectWrapper(PloneTestCase.PloneTestCase):
         self.failUnlessEqual(wrapped.getId(), 'doc')
         self.failUnlessEqual(wrapped.Title(), 'document')
         self.failUnlessEqual(wrapped.dummy, 'a dummy')
-        
+
     def beforeTearDown(self):
         _eioRegistry.unregister('dummy')
 
